<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Twenty_Seventeen
 * @since 1.0
 * @version 1.0
 */

get_header(); ?>

	<div class="wrap">
		<?php if ( is_home() && ! is_front_page() ) : ?>
			<header class="page-header">
				<h1 class="page-title"><?php single_post_title(); ?></h1>
			</header>
		<?php else : ?>
			<header class="page-header">

				<h2 class="page-title"><?php _e( 'Actualités', 'twentyseventeen' ); ?></h2>
				<br/>

				<div id="vignettes_actu">
					<div class="post_slider">

						<?php
						// 4 = id de la catégorie "Actualités"
						$post_args = array('category' => 4, 'posts_per_page' => 8); // mettre -1 pour afficher tous les posts, sinon mettre un nombre pour limiter (par défaut: 5 posts)
						$posts = get_posts($post_args);
						foreach ($posts as $the_post){ ?>
							<a href="<?php echo get_post_permalink($the_post); ?>"
							   class="post-img"
							   style="background-image:url(<?php
								$thumb_id = get_post_thumbnail_id($the_post);
								$thumb_url = wp_get_attachment_image_src($thumb_id,'medium', true);
								echo $thumb_url[0]; ?>);">
								<span><?php echo get_the_title($the_post);  ?></span>
							</a>
						<?php } ?>

					</div><!-- .post_slider -->
					<a class="more-link plusdactu" href="http://koya.li/mqp/category/actualites/"><span>Toute l'actualité</span></a>
				</div><!-- #vignettes_actu -->

				<br/><br/><br/>
				<h2 class="page-title"><?php _e( 'Accueil', 'twentyseventeen' ); ?></h2>

			</header>
		<?php endif; ?>
	</div><!-- .wrap -->

	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">

			<?php
			if ( have_posts() ) :

				/* Start the Loop */
				while ( have_posts() ) : the_post();

					/*
					 * Include the Post-Format-specific template for the content.
					 * If you want to override this in a child theme, then include a file
					 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
					 */
					get_template_part( 'template-parts/post/content', get_post_format() );

				endwhile;

				the_posts_pagination( array(
					'prev_text' => twentyseventeen_get_svg( array( 'icon' => 'arrow-left' ) ) . '<span class="screen-reader-text">' . __( 'Previous page', 'twentyseventeen' ) . '</span>',
					'next_text' => '<span class="screen-reader-text">' . __( 'Next page', 'twentyseventeen' ) . '</span>' . twentyseventeen_get_svg( array( 'icon' => 'arrow-right' ) ),
					'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'twentyseventeen' ) . ' </span>',
				) );

			else :

				get_template_part( 'template-parts/post/content', 'none' );

			endif;
			?>

		</main><!-- #main -->
	</div><!-- #primary -->
	<?php get_sidebar(); ?>


<?php get_footer(); ?>


<script type="text/javascript">
	jQuery(document).ready(function(){
		jQuery('.post_slider').slick({
			dots: true,
			arrows: false,
			infinite: true,
			autoplay: true,
			autoplaySpeed: 4000,
			speed: 500,
			slidesToShow: 4,
			slidesToScroll: 1,
			responsive: [
			{
			  breakpoint: 960,
			  settings: {
			    slidesToShow: 3,
			  }
			},
			{
			  breakpoint: 480,
			  settings: {
			    slidesToShow: 2,
			  }
			},
			{
			  breakpoint: 320,
			  settings: {
			    slidesToShow: 1,
			  }
			}
			// You can unslick at a given breakpoint now by adding:
			// settings: "unslick"
			// instead of a settings object
			]
		});
	});
</script>


<?php // laisser ouvert comme ça à la fin
